##  Introduce New Fact Sheet Type - Platform
In the Meta Model v4, [Platform](https://help.sap.com/docs/leanix/ea/platform-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model platforms. This includes best practices and applicable use cases, and common antipatterns.") is a new Fact Sheet type. To introduce the new Fact Sheet type, summarily, you do the following:
  1. Create a new Fact Sheet type named Platform.
  2. Add sections for Strategic Support and Implementation in the newly created Platform Fact Sheet.
  3. In the Strategic Support section, create relations to the Business Capability, Initiative, and Objective Fact Sheet types and fill in the necessary fields.
  4. In the Implementation section, create relations to the Application and IT Component Fact Sheet types and fill in the necessary fields.


**Note**
If you are using the optional Tech Platform Fact Sheet type in Meta Model v3, the simplest way to transition to Meta Model v4 is by editing the existing Tech Platform Fact Sheet type.
By following the instructions detailed in the sections below, add the necessary relations to other Fact Sheet types. You can retain the "Tech Platform" title; there's no obligation to change the name, especially if your organization is accustomed to the previous terminology.
Comprehensive Walkthrough for Each Step:
